pub struct FFIWordFlags(/* private fields */);Implementations
Sourceimpl FFIWordFlags
impl FFIWordFlags
pub const NONE: Self
pub const fn has_flags(self, flags: Self) -> bool
pub const fn add_flags(&mut self, flags: Self)
pub const fn remove_flags(&mut self, flags: Self)
pub const fn toggle_flags(&mut self, flags: Self)
pub const fn with_flags(self, flags: Self) -> Self
pub const fn without_flags(self, flags: Self) -> Self
pub const fn count_ones(self) -> u32
pub const fn pop_bottom_index(&mut self) -> Option<u32>
pub fn get_flags(self) -> Box<[(Self, &'static str)]>
Sourceimpl FFIWordFlags
impl FFIWordFlags
pub const ALL: Self
pub const ALL_FLAGS: &'static [Self]
pub const FLAG_NAMES: &'static [&'static str]
Sourcepub const HAS_DOLLAR: Self
pub const HAS_DOLLAR: Self
Dollar sign present.
Sourcepub const ASSIGNMENT: Self
pub const ASSIGNMENT: Self
This word is a variable assignment.
Sourcepub const SPLIT_SPACE: Self
pub const SPLIT_SPACE: Self
Split this word on “ “ regardless of IFS.
Sourcepub const NO_SPLIT: Self
pub const NO_SPLIT: Self
Do not perform word splitting on this word because IFS is empty string.
Sourcepub const NO_SPLIT2: Self
pub const NO_SPLIT2: Self
Don’t split word except for $@ expansion (using spaces) because context does not allow it.
Sourcepub const NO_COMMAND_SUBSTITUTION: Self
pub const NO_COMMAND_SUBSTITUTION: Self
Don’t perform command substitution on this word.
Sourcepub const ASSIGN_RHS: Self
pub const ASSIGN_RHS: Self
Word is RHS of an assignment statement.
Sourcepub const NO_ASSIGN_TILDE: Self
pub const NO_ASSIGN_TILDE: Self
Don’t do tilde expansion like an assignment statement.
Sourcepub const EXPAND_RHS: Self
pub const EXPAND_RHS: Self
Expanding word in ${paramOPword}
Sourcepub const COMPOUND_ASSIGNMENT: Self
pub const COMPOUND_ASSIGNMENT: Self
Compound assignment. (no idea what that means, better look it up.) // TODO
Sourcepub const ASSIGN_BUILTIN: Self
pub const ASSIGN_BUILTIN: Self
Word is a builtin command that takes assignments
Sourcepub const ASSIGN_ARG: Self
pub const ASSIGN_ARG: Self
Word is assignment argument to command.
Sourcepub const HAS_QUOTED_NULL: Self
pub const HAS_QUOTED_NULL: Self
Word contains a quoted null character.
Sourcepub const DOUBLE_QUOTE: Self
pub const DOUBLE_QUOTE: Self
Word should be treated as if double-quoted. (Unused)
Sourcepub const NO_PROCESS_SUBSTITUTION: Self
pub const NO_PROCESS_SUBSTITUTION: Self
Don’t perform process substitution.
Sourcepub const SAW_QUOTED_NULL: Self
pub const SAW_QUOTED_NULL: Self
Word contained a quoted null that was removed.
Sourcepub const ASSIGN_ASSOC: Self
pub const ASSIGN_ASSOC: Self
Word looks like associative array assignment.
Sourcepub const ASSIGN_ARRAY: Self
pub const ASSIGN_ARRAY: Self
Word looks like a compound indexed array assignment.
Sourcepub const ARRAY_INDEX: Self
pub const ARRAY_INDEX: Self
Word is an array index being expanded.
Sourcepub const ASSIGN_GLOBAL: Self
pub const ASSIGN_GLOBAL: Self
Word is a global assignment to declare
Sourcepub const COMPLETION: Self
pub const COMPLETION: Self
Word is being expanded for completion.
Sourcepub const CHECK_LOCAL: Self
pub const CHECK_LOCAL: Self
Check for local vars on assignment.
Sourcepub const FORCE_LOCAL: Self
pub const FORCE_LOCAL: Self
Force assignment to be local variables, non-fatal on assignment errors.]
pub const fn get_has_dollar(self) -> bool
pub const fn add_has_dollar(&mut self)
pub const fn remove_has_dollar(&mut self)
pub const fn set_has_dollar(&mut self, on: bool)
pub const fn toggle_has_dollar(&mut self)
pub const fn with_has_dollar(self) -> Self
pub const fn without_has_dollar(self) -> Self
pub const fn get_quoted(self) -> bool
pub const fn add_quoted(&mut self)
pub const fn remove_quoted(&mut self)
pub const fn set_quoted(&mut self, on: bool)
pub const fn toggle_quoted(&mut self)
pub const fn with_quoted(self) -> Self
pub const fn without_quoted(self) -> Self
pub const fn get_assignment(self) -> bool
pub const fn add_assignment(&mut self)
pub const fn remove_assignment(&mut self)
pub const fn set_assignment(&mut self, on: bool)
pub const fn toggle_assignment(&mut self)
pub const fn with_assignment(self) -> Self
pub const fn without_assignment(self) -> Self
pub const fn get_split_space(self) -> bool
pub const fn add_split_space(&mut self)
pub const fn remove_split_space(&mut self)
pub const fn set_split_space(&mut self, on: bool)
pub const fn toggle_split_space(&mut self)
pub const fn with_split_space(self) -> Self
pub const fn without_split_space(self) -> Self
pub const fn get_no_split(self) -> bool
pub const fn add_no_split(&mut self)
pub const fn remove_no_split(&mut self)
pub const fn set_no_split(&mut self, on: bool)
pub const fn toggle_no_split(&mut self)
pub const fn with_no_split(self) -> Self
pub const fn without_no_split(self) -> Self
pub const fn get_no_glob(self) -> bool
pub const fn add_no_glob(&mut self)
pub const fn remove_no_glob(&mut self)
pub const fn set_no_glob(&mut self, on: bool)
pub const fn toggle_no_glob(&mut self)
pub const fn with_no_glob(self) -> Self
pub const fn without_no_glob(self) -> Self
pub const fn get_no_split2(self) -> bool
pub const fn add_no_split2(&mut self)
pub const fn remove_no_split2(&mut self)
pub const fn set_no_split2(&mut self, on: bool)
pub const fn toggle_no_split2(&mut self)
pub const fn with_no_split2(self) -> Self
pub const fn without_no_split2(self) -> Self
pub const fn get_tilde_exp(self) -> bool
pub const fn add_tilde_exp(&mut self)
pub const fn remove_tilde_exp(&mut self)
pub const fn set_tilde_exp(&mut self, on: bool)
pub const fn toggle_tilde_exp(&mut self)
pub const fn with_tilde_exp(self) -> Self
pub const fn without_tilde_exp(self) -> Self
pub const fn get_dollar_at(self) -> bool
pub const fn add_dollar_at(&mut self)
pub const fn remove_dollar_at(&mut self)
pub const fn set_dollar_at(&mut self, on: bool)
pub const fn toggle_dollar_at(&mut self)
pub const fn with_dollar_at(self) -> Self
pub const fn without_dollar_at(self) -> Self
pub const fn get_array_ref(self) -> bool
pub const fn add_array_ref(&mut self)
pub const fn remove_array_ref(&mut self)
pub const fn set_array_ref(&mut self, on: bool)
pub const fn toggle_array_ref(&mut self)
pub const fn with_array_ref(self) -> Self
pub const fn without_array_ref(self) -> Self
pub const fn get_no_command_substitution(self) -> bool
pub const fn add_no_command_substitution(&mut self)
pub const fn remove_no_command_substitution(&mut self)
pub const fn set_no_command_substitution(&mut self, on: bool)
pub const fn toggle_no_command_substitution(&mut self)
pub const fn with_no_command_substitution(self) -> Self
pub const fn without_no_command_substitution(self) -> Self
pub const fn get_assign_rhs(self) -> bool
pub const fn add_assign_rhs(&mut self)
pub const fn remove_assign_rhs(&mut self)
pub const fn set_assign_rhs(&mut self, on: bool)
pub const fn toggle_assign_rhs(&mut self)
pub const fn with_assign_rhs(self) -> Self
pub const fn without_assign_rhs(self) -> Self
pub const fn get_no_tilde(self) -> bool
pub const fn add_no_tilde(&mut self)
pub const fn remove_no_tilde(&mut self)
pub const fn set_no_tilde(&mut self, on: bool)
pub const fn toggle_no_tilde(&mut self)
pub const fn with_no_tilde(self) -> Self
pub const fn without_no_tilde(self) -> Self
pub const fn get_no_assign_tilde(self) -> bool
pub const fn add_no_assign_tilde(&mut self)
pub const fn remove_no_assign_tilde(&mut self)
pub const fn set_no_assign_tilde(&mut self, on: bool)
pub const fn toggle_no_assign_tilde(&mut self)
pub const fn with_no_assign_tilde(self) -> Self
pub const fn without_no_assign_tilde(self) -> Self
pub const fn get_expand_rhs(self) -> bool
pub const fn add_expand_rhs(&mut self)
pub const fn remove_expand_rhs(&mut self)
pub const fn set_expand_rhs(&mut self, on: bool)
pub const fn toggle_expand_rhs(&mut self)
pub const fn with_expand_rhs(self) -> Self
pub const fn without_expand_rhs(self) -> Self
pub const fn get_compound_assignment(self) -> bool
pub const fn add_compound_assignment(&mut self)
pub const fn remove_compound_assignment(&mut self)
pub const fn set_compound_assignment(&mut self, on: bool)
pub const fn toggle_compound_assignment(&mut self)
pub const fn with_compound_assignment(self) -> Self
pub const fn without_compound_assignment(self) -> Self
pub const fn get_assign_builtin(self) -> bool
pub const fn add_assign_builtin(&mut self)
pub const fn remove_assign_builtin(&mut self)
pub const fn set_assign_builtin(&mut self, on: bool)
pub const fn toggle_assign_builtin(&mut self)
pub const fn with_assign_builtin(self) -> Self
pub const fn without_assign_builtin(self) -> Self
pub const fn get_assign_arg(self) -> bool
pub const fn add_assign_arg(&mut self)
pub const fn remove_assign_arg(&mut self)
pub const fn set_assign_arg(&mut self, on: bool)
pub const fn toggle_assign_arg(&mut self)
pub const fn with_assign_arg(self) -> Self
pub const fn without_assign_arg(self) -> Self
pub const fn get_has_quoted_null(self) -> bool
pub const fn add_has_quoted_null(&mut self)
pub const fn remove_has_quoted_null(&mut self)
pub const fn set_has_quoted_null(&mut self, on: bool)
pub const fn toggle_has_quoted_null(&mut self)
pub const fn with_has_quoted_null(self) -> Self
pub const fn without_has_quoted_null(self) -> Self
pub const fn get_double_quote(self) -> bool
pub const fn add_double_quote(&mut self)
pub const fn remove_double_quote(&mut self)
pub const fn set_double_quote(&mut self, on: bool)
pub const fn toggle_double_quote(&mut self)
pub const fn with_double_quote(self) -> Self
pub const fn without_double_quote(self) -> Self
pub const fn get_no_process_substitution(self) -> bool
pub const fn add_no_process_substitution(&mut self)
pub const fn remove_no_process_substitution(&mut self)
pub const fn set_no_process_substitution(&mut self, on: bool)
pub const fn toggle_no_process_substitution(&mut self)
pub const fn with_no_process_substitution(self) -> Self
pub const fn without_no_process_substitution(self) -> Self
pub const fn get_saw_quoted_null(self) -> bool
pub const fn add_saw_quoted_null(&mut self)
pub const fn remove_saw_quoted_null(&mut self)
pub const fn set_saw_quoted_null(&mut self, on: bool)
pub const fn toggle_saw_quoted_null(&mut self)
pub const fn with_saw_quoted_null(self) -> Self
pub const fn without_saw_quoted_null(self) -> Self
pub const fn get_assign_assoc(self) -> bool
pub const fn add_assign_assoc(&mut self)
pub const fn remove_assign_assoc(&mut self)
pub const fn set_assign_assoc(&mut self, on: bool)
pub const fn toggle_assign_assoc(&mut self)
pub const fn with_assign_assoc(self) -> Self
pub const fn without_assign_assoc(self) -> Self
pub const fn get_assign_array(self) -> bool
pub const fn add_assign_array(&mut self)
pub const fn remove_assign_array(&mut self)
pub const fn set_assign_array(&mut self, on: bool)
pub const fn toggle_assign_array(&mut self)
pub const fn with_assign_array(self) -> Self
pub const fn without_assign_array(self) -> Self
pub const fn get_array_index(self) -> bool
pub const fn add_array_index(&mut self)
pub const fn remove_array_index(&mut self)
pub const fn set_array_index(&mut self, on: bool)
pub const fn toggle_array_index(&mut self)
pub const fn with_array_index(self) -> Self
pub const fn without_array_index(self) -> Self
pub const fn get_assign_global(self) -> bool
pub const fn add_assign_global(&mut self)
pub const fn remove_assign_global(&mut self)
pub const fn set_assign_global(&mut self, on: bool)
pub const fn toggle_assign_global(&mut self)
pub const fn with_assign_global(self) -> Self
pub const fn without_assign_global(self) -> Self
pub const fn get_no_brace(self) -> bool
pub const fn add_no_brace(&mut self)
pub const fn remove_no_brace(&mut self)
pub const fn set_no_brace(&mut self, on: bool)
pub const fn toggle_no_brace(&mut self)
pub const fn with_no_brace(self) -> Self
pub const fn without_no_brace(self) -> Self
pub const fn get_completion(self) -> bool
pub const fn add_completion(&mut self)
pub const fn remove_completion(&mut self)
pub const fn set_completion(&mut self, on: bool)
pub const fn toggle_completion(&mut self)
pub const fn with_completion(self) -> Self
pub const fn without_completion(self) -> Self
pub const fn get_check_local(self) -> bool
pub const fn add_check_local(&mut self)
pub const fn remove_check_local(&mut self)
pub const fn set_check_local(&mut self, on: bool)
pub const fn toggle_check_local(&mut self)
pub const fn with_check_local(self) -> Self
pub const fn without_check_local(self) -> Self
pub const fn get_force_local(self) -> bool
pub const fn add_force_local(&mut self)
pub const fn remove_force_local(&mut self)
pub const fn set_force_local(&mut self, on: bool)
pub const fn toggle_force_local(&mut self)
pub const fn with_force_local(self) -> Self
pub const fn without_force_local(self) -> Self